/*
Copyright 2015-2016, Manuel Bichler
WWW: <http://dbai.tuwien.ac.at/proj/lpopt/>

This file is part of lpopt.

lpopt is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

lpopt is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with lpopt.  If not, see <http://www.gnu.org/licenses/>.
*/

#pragma once

// Only include FlexLexer.h if it hasn't been already included
#if ! defined(yyFlexLexerOnce)
#include <FlexLexer.h>
#endif

// Override the interface for yylex since we namespaced it
#undef YY_DECL
#define YY_DECL int parser::FlexScanner::yylex()

/* before, in Driver.h, it was (from Berni):
#define YY_DECL                                \
 yy::Parser::token_type                        \
 yylex(yy::Parser::semantic_type* yylval,      \
       yy::Parser::location_type* yylloc)
YY_DECL;
*/


// Include Bison for types / tokens
#include "parser.hh"


namespace parser {
	class FlexScanner : public yyFlexLexer {
		public:
			FlexScanner(FLEX_STD istream* in = 0, FLEX_STD ostream* out = 0) : yyFlexLexer(in, out) { }
			
			// save the pointer to yylval so we can change it, and invoke scanner
			int yylex(parser::Parser::semantic_type * lval, parser::Parser::location_type* lloc) { yylval = lval; yylloc=lloc; return yylex(); }
		
		private:
			// Scanning function created by Flex; make this private to force usage
			// of the overloaded method so we can get a pointer to Bison's yylval and yylloc
			int yylex();
			
			// point to yylval (provided by Bison in overloaded yylex)
			parser::Parser::semantic_type * yylval;
			// point to yylloc
			parser::Parser::location_type* yylloc;
	};
}

